@@ -49,7 +49,8 @@ def timed_print():
     start_time = time.time()
     def do_print(level, prefix, text):
         td = time.time() - start_time
-        print('{:.3f} [{}] {}: {}'.format(td, level, prefix, text), flush=True)
+        print('{:.3f} [{}] {}: {}'.format(td, level, prefix, text.strip()), flush=True)
+    return do_print
 
 
 class MpvTestCase(unittest.TestCase):
@@ -210,6 +211,11 @@ class TestProperties(MpvTestCase):
             # See comment in test_property_decoding_invalid_utf8
             self.m.osd.alang
 
+    def test_dict_valued_property(self):
+        nasty_stuff = '\xe2\x80\x8e Mozilla/5.0 Foobar                 \xe2\x80\x8e  \xe2\x80\x81'
+        self.m.ytdl_raw_options = {'user-agent': nasty_stuff}
+        self.assertEqual(self.m.ytdl_raw_options, {'user-agent': nasty_stuff})
+
     def test_option_read(self):
         self.m.loop = 'inf'
         self.m.play(TESTVID)
@@ -917,11 +923,10 @@ class RegressionTests(MpvTestCase):
 
     def test_wait_for_property_concurrency(self):
         players = [mpv.MPV(vo=testvo, loglevel='debug', log_handler=timed_print()) for i in range(2)]
-
         try:
             for _ in range(150):
                 for player in players:
-                    player.play('tests/test.webm')
+                    player.loadfile('tests/test.webm', loop='inf')
                 for player in players:
                     player.wait_for_property('seekable')
                 for player in players:
